#
# spec file for package ghc-splitmix
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name splitmix
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.1.1
Release:        1.3
Summary:        Fast Splittable PRNG
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-HUnit-prof
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-async-prof
BuildRequires:  ghc-base-compat-batteries-devel
BuildRequires:  ghc-base-compat-batteries-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-math-functions-devel
BuildRequires:  ghc-math-functions-prof
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-process-prof
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-random-prof
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-hunit-devel
BuildRequires:  ghc-test-framework-hunit-prof
BuildRequires:  ghc-test-framework-prof
BuildRequires:  ghc-tf-random-devel
BuildRequires:  ghc-tf-random-prof
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-vector-prof
%endif

%description
Pure Haskell implementation of SplitMix described in

Guy L. Steele, Jr., Doug Lea, and Christine H. Flood. 2014. Fast splittable
pseudorandom number generators. In Proceedings of the 2014 ACM International
Conference on Object Oriented Programming Systems Languages & Applications
(OOPSLA '14). ACM, New York, NY, USA, 453-472. DOI:
<https://doi.org/10.1145/2660193.2660195>

The paper describes a new algorithm /SplitMix/ for /splittable/ pseudorandom
number generator that is quite fast: 9 64 bit arithmetic/logical operations per
64 bits generated.

/SplitMix/ is tested with two standard statistical test suites (DieHarder and
TestU01, this implementation only using the former) and it appears to be
adequate for "everyday" use, such as Monte Carlo algorithms and randomized data
structures where speed is important.

In particular, it __should not be used for cryptographic or security
applications__, because generated sequences of pseudorandom values are too
predictable (the mixing functions are easily inverted, and two successive
outputs suffice to reconstruct the internal state).

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc Changelog.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Dec 19 2024 Peter Simons <psimons@suse.com>
- Update splitmix to version 0.1.1.
  [#] 0.1.1
  - Drop support for GHCs prior 8.6.5
  - Support GHC-9.12
* Tue Apr  2 2024 Peter Simons <psimons@suse.com>
- Update splitmix to version 0.1.0.5 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Oct  3 2023 Peter Simons <psimons@suse.com>
- Update splitmix to version 0.1.0.5.
  Upstream has not updated the file "Changelog.md" since the last
  release.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Jan 15 2023 Peter Simons <psimons@suse.com>
- Update splitmix to version 0.1.0.4 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Aug 10 2022 Peter Simons <psimons@suse.com>
- Update splitmix to version 0.1.0.4 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Nov  1 2021 psimons@suse.com
- Update splitmix to version 0.1.0.4.
  [#] 0.1.0.4
  - Add TestU01 test-suite
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Fri Oct 23 2020 psimons@suse.com
- Update splitmix to version 0.1.0.3.
  [#] 0.1.0.3
  - Fix oops bugs in 0.1.0.2
  - It's lowercase `windows.h`.
    I blame Microsoft docs for using capital case `Windows.h` in the docs.
    https://docs.microsoft.com/en-us/windows/win32/api/processthreadsapi/nf-processthreadsapi-getprocessid
  - accidental `shiftL` vs `shiftR` mixup for 32-bit generator initialization.
    Doesn't affect Linux.
* Tue Oct 20 2020 psimons@suse.com
- Update splitmix to version 0.1.0.2.
  [#] 0.1.0.2
  - Drop `time` dependency in favour of handcoded initialization
  - On Unix platforms we use `/dev/urandom` if it exists,
    otherwise use `gettimeofday`, `clock` and `getpid`.
  - On Windows we use `GetCurrentProcessID`, `GetCurrentThreadId()`,
    `GetTickCount`, `GetSystemTime` and `QueryPerformanceCounter`.
  - On GHCJS use `Math.random()`
  - Using `time` is a fallback option (e.g. for Hugs).
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Fri Aug  7 2020 psimons@suse.com
- Update splitmix to version 0.1.0.1.
  [#] 0.1.0.1
  - Add `INLINEABLE` pragmas to `bitmaskWithRejection*` functions
  - Support GHC-9.0
* Tue Jul  7 2020 psimons@suse.com
- Update splitmix to version 0.1.
  [#] 0.1
  - Drop `random` dependency unconditionally.
    https://github.com/phadej/splitmix/issues/34
* Tue Jun  9 2020 psimons@suse.com
- Update splitmix to version 0.0.5.
  - Add `nextInteger`
  - Use smaller range in `bitmaskWithRejection32` and `64`, when
    upper bound is 2^n - 1. This changes generated values when they
    were on the boundary.
* Thu Feb 27 2020 psimons@suse.com
- Update splitmix to version 0.0.4.
  - Add `bitmaskWithRejection32'` and `bitmaskWithRejection64'`
    which generate numbers in closed range `[0, n]`.
  - Unticked variants generate in closed-open range `[0, n)`.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Wed Jul 31 2019 psimons@suse.com
- Update splitmix to version 0.0.3.
  - Add `System.Random.SplitMix32` module
  - Add `bitmaskWithRejection32` and `bitmaskWithRejection64` module
  - Add `nextWord32`, `nextTwoWord32` and `nextFloat`
  - Add `random` flag, dropping dependency on `random`
    (breaks things, e.g. `QuickCheck`, when disabled).
* Thu Mar 28 2019 psimons@suse.com
- Add splitmix at version 0.0.2.
